@@ -1,8 +1,11 @@
 use super::*;
+#[cfg(feature = "verify")]
 use swc_common::{Span, Spanned};
+#[cfg(feature = "verify")]
 use swc_ecma_visit::{noop_visit_type, Visit, VisitWith};
 
 impl<'a, I: Tokens> Parser<I> {
+    #[cfg(feature = "verify")]
     pub(in crate::parser) fn verify_expr(&mut self, expr: Box<Expr>) -> PResult<Box<Expr>> {
         let mut v = Verifier { errors: vec![] };
 
@@ -14,12 +17,19 @@ impl<'a, I: Tokens> Parser<I> {
 
         return Ok(expr);
     }
+
+    #[cfg(not(feature = "verify"))]
+    pub(in crate::parser) fn verify_expr(&mut self, expr: Box<Expr>) -> PResult<Box<Expr>> {
+        Ok(expr)
+    }
 }
 
+#[cfg(feature = "verify")]
 pub(super) struct Verifier {
     pub errors: Vec<(Span, SyntaxError)>,
 }
 
+#[cfg(feature = "verify")]
 impl Visit for Verifier {
     noop_visit_type!();
 
